==> 8.2.zip: 8.2/update_action_workorder_image_file_react.php <==
<?php
require_once('config.php');
require_once('utility_image.php');

//$uploaddir = "C:\\wamp64\\www\\CMMS_Standard\\temp\\";
$uploaddir;
$error_message;
$valid = true;
$json_return = array();
$json_return2 = array();
$json_return = [];

$mst_RowID;


if ($_SERVER["REQUEST_METHOD"] == "POST") { 

	$count    	   	= $_REQUEST["count"];
	$json 			= $_REQUEST["json"];	
	$json 			= json_decode($json);
	$rowid			= $json->data->rowid;
	$site_cd		= $json->data->site_cd;
	$EMPID			= $json->data->EMPID;
	$LOGINID		= $json->data->LOGINID;
	$folder			= $json->data->folder;
	$dvc_id			= $json->data->dvc_id;
	$base64string	= $_REQUEST["base64string"];
	
	$uploaddir = "C:\\wamp64\\www\\".$folder."\\temp_".$dvc_id."\\";
	
	if (!is_dir($uploaddir)) {
		mkdir($uploaddir, 0777, true);
		mkdir($uploaddir."\\thumbnail\\", 0777, true);
	}
	
	
	$sql = "SELECT mst_RowID From wko_ref WHERE site_cd = '".$site_cd."' AND mst_RowID = ".$rowid." AND type = 'A' AND column2 = 'SIGN'";	

	$stmt = sqlsrv_query( $conn, $sql);	
			
	if( !$stmt ) {
		$error_message = "Error update table (itm_mst)";
		returnError($error_message);
		die( print_r( sqlsrv_errors(), true));
	}
	do {
		 while ($row = sqlsrv_fetch_array($stmt, SQLSRV_FETCH_ASSOC)) {
		 
		 $mst_RowID = $row['mst_RowID'];	 
			 
	   }
	} while ( sqlsrv_next_result($stmt));
	
	if(empty($mst_RowID)){
		
		$parts   	  = explode(";base64,", $base64string);
		$imageparts   = explode("image/", @$parts[0]);
		$imagetype    = $imageparts[1];
		$imagebase64  = base64_decode($parts[1]);
		$filename = 'Acknowledge_sign'.floor(microtime(true)*1000).'.jpg';
		$file         = $uploaddir . uniqid() . '.png';
		file_put_contents($file, $imagebase64);
		$fullPathwithfileName = $file;
		
		
		
		$datastring= file_get_contents($fullPathwithfileName);
		$data=unpack("H*hex", $datastring);
		//echo $data;
		
		$sql = "INSERT INTO wko_ref	(	site_cd, 			audit_user, 		audit_date, 		status,					column1, 			column2, 
										FILE_NAME, 			type, 				mst_rowid, 			attachment,				mbl_audit_user,		mbl_audit_date) 
							VALUES 	(	'".$site_cd."',		'".$EMPID."', 		getdate(),			'Saved', 				'Native', 			'SIGN', 
										'".$filename."','A', 				".$rowid.", 		0x".$data['hex'].",		'".$LOGINID."',		getdate()) SELECT SCOPE_IDENTITY() as rowid";
			
		$stmt = sqlsrv_query( $conn, $sql);				
						
		if( !$stmt ) {
			$error_message = "Error insert table (wko_ref)";
			returnError($error_message);
			die( print_r( sqlsrv_errors(), true));
		}else{
			unlink($fullPathwithfileName);
		}
		$json_wko_ref = array();
		do {
			while ($row = sqlsrv_fetch_array($stmt, SQLSRV_FETCH_ASSOC)) {
				$json_wko_ref['rowid'] = $row['rowid'];
				$json_wko_ref['action'] = "INSERT";
				array_push($json_return2, $json_wko_ref);
				
			}
		} while ( sqlsrv_next_result($stmt) );
		$json_return['wko_ref'] = $json_return2;
		

		
	}else{
		
		$parts   	  = explode(";base64,", $base64string);
		$imageparts   = explode("image/", @$parts[0]);
		$imagetype    = $imageparts[1];
		$imagebase64  = base64_decode($parts[1]);
		$filename = 'Acknowledge_sign'.floor(microtime(true)*1000).'.jpg';
		$file         = $uploaddir . uniqid() . '.png';
		file_put_contents($file, $imagebase64);
		$fullPathwithfileName = $file;
	
		$datastring= file_get_contents($fullPathwithfileName);
		$data=unpack("H*hex", $datastring);
		
		
		$sql ="UPDATE 	wko_ref 
					SET  		
							attachment=0x".$data['hex'].",
							audit_user=?,
							audit_date=getdate(),	
							mbl_audit_user=?,	
							mbl_audit_date=getdate() 														
					where 	site_cd=? 
					and  	mst_rowid =? 
					and 	column2 =?  
					and 	type =? "; 
			
			$params = array($LOGINID,$LOGINID,$site_cd,$rowid,'SIGN','A');					
			
		
			$stmt_wko_ref = sqlsrv_query( $conn, $sql,$params);			
		
			if( !$stmt_wko_ref ) {
				print_r( sqlsrv_errors(), true);
				
				$error_message = "Error update table (UPDATE wko_ref 123)";
				returnError($error_message);
				die( print_r( sqlsrv_errors(), true));
			}
			
			$json_wko_ref = array();
			do {
				while ($row = sqlsrv_fetch_array($stmt_wko_ref, SQLSRV_FETCH_ASSOC)) {
					$json_wko_ref['rowid'] = $row['rowid'];
					$json_wko_ref['action'] = "INSERT";
					array_push($json_return2, $json_wko_ref);
				 	
				}
		   } while ( sqlsrv_next_result($stmt_wko_ref) );	
				
			$json_return['wko_ref'] = $json_return2;
		
		
		
	}	
	
}
		
if ($valid) {
	//sqlsrv_free_stmt( $stmt);
	sqlsrv_close( $conn);	
	
	//Declare NULL Array since no records inserted, in future will insert as wko_ref
	//$json = array();
	
	returnData($json_return);	
}

function insertImage($image){

}

function returnData($json_return){
	$returnData = array(
	'status' => 'SUCCESS',
	'message' => 'Acknowledge Successfully',
	'data' => $json_return);
	
	echo json_encode($returnData);
}

function returnError($error_message){
	$json = array();
	
	$returnData = array(
	'status' => 'ERROR',
	'message' => $error_message,
	'data' => $json);
	
	echo json_encode($returnData);
	
	
	//sqlsrv_close( $conn);	
		
	exit();
}


?>

==> 8.8.zip: 8.8/update_action_workorder_image_file_react.php <==
<?php
require_once('config.php');
require_once('utility_image.php');

//$uploaddir = "C:\\wamp64\\www\\CMMS_Standard\\temp\\";
$uploaddir;
$error_message;
$valid = true;
$json_return = array();
$json_return2 = array();
$json_return = [];

$mst_RowID;


if ($_SERVER["REQUEST_METHOD"] == "POST") { 

	$count    	   	= $_REQUEST["count"];
	$json 			= $_REQUEST["json"];	
	$json 			= json_decode($json);
	$rowid			= $json->data->rowid;
	$site_cd		= $json->data->site_cd;
	$EMPID			= $json->data->EMPID;
	$LOGINID		= $json->data->LOGINID;
	$folder			= $json->data->folder;
	$dvc_id			= $json->data->dvc_id;
	$base64string	= $_REQUEST["base64string"];
	
	$uploaddir = "C:\\wamp64\\www\\".$folder."\\temp_".$dvc_id."\\";
	
	if (!is_dir($uploaddir)) {
		mkdir($uploaddir, 0777, true);
		mkdir($uploaddir."\\thumbnail\\", 0777, true);
	}
	
	
	$sql = "SELECT mst_RowID From wko_ref WHERE site_cd = '".$site_cd."' AND mst_RowID = ".$rowid." AND type = 'A' AND column2 = 'SIGN'";	

	$stmt = sqlsrv_query( $conn, $sql);	
			
	if( !$stmt ) {
		$error_message = "Error update table (itm_mst)";
		returnError($error_message);
		die( print_r( sqlsrv_errors(), true));
	}
	do {
		 while ($row = sqlsrv_fetch_array($stmt, SQLSRV_FETCH_ASSOC)) {
		 
		 $mst_RowID = $row['mst_RowID'];	 
			 
	   }
	} while ( sqlsrv_next_result($stmt));
	
	if(empty($mst_RowID)){
		
		$parts   	  = explode(";base64,", $base64string);
		$imageparts   = explode("image/", @$parts[0]);
		$imagetype    = $imageparts[1];
		$imagebase64  = base64_decode($parts[1]);
		$random_id = rand(100000, 999999);
		$filename = 'Acknowledge_sign_'.$random_id.'.jpg';
		$file         = $uploaddir . uniqid() . '.png';
		file_put_contents($file, $imagebase64);
		$fullPathwithfileName = $file;
		
		
		
		$datastring= file_get_contents($fullPathwithfileName);
		$data=unpack("H*hex", $datastring);
		//echo $data;
		
		$sql = "INSERT INTO wko_ref	(	site_cd, 			audit_user, 		audit_date, 		status,					column1, 			column2, 
										FILE_NAME, 			type, 				mst_rowid, 			attachment,				mbl_audit_user,		mbl_audit_date) 
							VALUES 	(	'".$site_cd."',		'".$EMPID."', 		getdate(),			'Saved', 				'Native', 			'SIGN', 
										'".$filename."','A', 				".$rowid.", 		0x".$data['hex'].",		'".$LOGINID."',		getdate()) SELECT SCOPE_IDENTITY() as rowid";
			
		$stmt = sqlsrv_query( $conn, $sql);				
						
		if( !$stmt ) {
			$error_message = "Error insert table (wko_ref)";
			returnError($error_message);
			die( print_r( sqlsrv_errors(), true));
		}else{
			unlink($fullPathwithfileName);
		}
		$json_wko_ref = array();
		do {
			while ($row = sqlsrv_fetch_array($stmt, SQLSRV_FETCH_ASSOC)) {
				$json_wko_ref['rowid'] = $row['rowid'];
				$json_wko_ref['action'] = "INSERT";
				array_push($json_return2, $json_wko_ref);
				
			}
		} while ( sqlsrv_next_result($stmt) );
		$json_return['wko_ref'] = $json_return2;
		

		
	}else{
		
		$parts   	  = explode(";base64,", $base64string);
		$imageparts   = explode("image/", @$parts[0]);
		$imagetype    = $imageparts[1];
		$imagebase64  = base64_decode($parts[1]);
		$random_id = rand(100000, 999999);
		$filename = 'Acknowledge_sign_'.$random_id.'.jpg';
		$file         = $uploaddir . uniqid() . '.png';
		file_put_contents($file, $imagebase64);
		$fullPathwithfileName = $file;
	
		$datastring= file_get_contents($fullPathwithfileName);
		$data=unpack("H*hex", $datastring);
		
		
		$sql ="UPDATE 	wko_ref 
					SET  		
							attachment=0x".$data['hex'].",
							audit_user=?,
							audit_date=getdate(),	
							mbl_audit_user=?,	
							mbl_audit_date=getdate() 														
					where 	site_cd=? 
					and  	mst_rowid =? 
					and 	column2 =?  
					and 	type =? "; 
			
			$params = array($LOGINID,$LOGINID,$site_cd,$rowid,'SIGN','A');					
			
		
			$stmt_wko_ref = sqlsrv_query( $conn, $sql,$params);			
		
			if( !$stmt_wko_ref ) {
				print_r( sqlsrv_errors(), true);
				
				$error_message = "Error update table (UPDATE wko_ref 123)";
				returnError($error_message);
				die( print_r( sqlsrv_errors(), true));
			}
			
			$json_wko_ref = array();
			do {
				while ($row = sqlsrv_fetch_array($stmt_wko_ref, SQLSRV_FETCH_ASSOC)) {
					$json_wko_ref['rowid'] = $row['rowid'];
					$json_wko_ref['action'] = "INSERT";
					array_push($json_return2, $json_wko_ref);
				 	
				}
		   } while ( sqlsrv_next_result($stmt_wko_ref) );	
				
			$json_return['wko_ref'] = $json_return2;
		
		
		
	}	
	
}
		
if ($valid) {
	//sqlsrv_free_stmt( $stmt);
	sqlsrv_close( $conn);	
	
	//Declare NULL Array since no records inserted, in future will insert as wko_ref
	//$json = array();
	
	returnData($json_return);	
}

function insertImage($image){

}

function returnData($json_return){
	$returnData = array(
	'status' => 'SUCCESS',
	'message' => 'Acknowledge Successfully',
	'data' => $json_return);
	
	echo json_encode($returnData);
}

function returnError($error_message){
	$json = array();
	
	$returnData = array(
	'status' => 'ERROR',
	'message' => $error_message,
	'data' => $json);
	
	echo json_encode($returnData);
	
	
	//sqlsrv_close( $conn);	
		
	exit();
}


?>
